@@ -15,7 +15,18 @@ class Hosts(object):
 
     def load(self):
         if os.path.exists(self.f):
-            self.hosts = yaml.safe_load(open(self.f).read())['all']['hosts']
+            inventory = yaml.safe_load(open(self.f).read())
+            group = inventory.get('live')
+            if group is None:
+                # backward compatibility: 'all' group was used before
+                try:
+                    group = inventory['all']
+                except KeyError:
+                    raise Exception(f"Missing expected group 'live' in {self.f!r}")
+                self.hosts = group['hosts']
+                self.save()
+            else:
+                self.hosts = group['hosts']
         else:
             self.hosts = {}
         return self
@@ -31,7 +42,7 @@ class Hosts(object):
             os.makedirs(self.d)
         content = yaml.dump(
             {
-                'all': {
+                'live': {
                     'hosts': self.hosts,
                 },
             }
