@@ -12,12 +12,13 @@ from enough.common import retry
 log = logging.getLogger(__name__)
 
 
-def libvirt_install(config_dir, share_dir, domain, ip):
-    Hosts(config_dir).create_or_update('libvirt-hypervisor', ip, '22')
+def libvirt_install(config_dir, share_dir, **kwargs):
+    Hosts(config_dir).create_or_update('libvirt-hypervisor', kwargs['host'], '22')
     playbook = ansible_utils.Playbook(config_dir, share_dir)
     playbook.run('--private-key', f'{config_dir}/infrastructure_key',
                  '--limit', 'libvirt-hypervisor,localhost',
-                 f'{share_dir}/libvirt-hypervisor-playbook.yml')
+                 '--extra-vars', f'vpn={kwargs.get("vpn","NOOP")}',
+                 f'{share_dir}/playbooks/libvirt-hypervisor/libvirt-hypervisor-playbook.yml')
     return True
 
 
