@@ -9,8 +9,7 @@ class CreateTestSubdomain(ShowOne):
     "Create and delegate a test subdomain, if possible"
 
     def take_action(self, parsed_args):
-        clouds_file = f'{settings.CONFIG_DIR}/inventory/group_vars/all/clouds.yml'
-        h = openstack.Heat(settings.CONFIG_DIR, clouds_file)
+        h = openstack.Heat(settings.CONFIG_DIR)
         r = h.create_test_subdomain(self.app.options.domain)
         columns = ('name',)
         data = (r,)
