@@ -108,6 +108,33 @@ def test_pipelining_is_enabled_2(monkeypatch):
                        "-athat='ansible_pipelining'")
 
 
+def test_ansible_environment(monkeypatch):
+    ansible = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR,
+                                    ['localhost,'])
+
+    # The environment variable must be defined once ansible_utils.Ansible has
+    # been called (we expect environment variables to be evaluated as late as
+    # possible).
+    monkeypatch.setenv('TEST_CANARY', 'test_value')
+    ansible.bake()('all', '-llocalhost', '-massert',
+                   '''-athat="lookup('env', 'TEST_CANARY') == 'test_value'"''')
+
+
+def test_playbook_environment(monkeypatch):
+    playbook = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
+
+    # The environment variable must be defined once ansible_utils.Playbook has
+    # been called (we expect environment variables to be evaluated as late as
+    # possible).
+    monkeypatch.setenv('GITLAB_RUNNER_TOKEN', 'test_value')
+    monkeypatch.setenv('ANSIBLE_VERBOSITY', '2')
+    # default value of role default variable 'gitlab_runner__token' is the
+    # 'GITLAB_RUNNER_TOKEN' environment variable (using 'env' lookup)
+    value = playbook.get_role_variable('debops.gitlab_runner', 'gitlab_runner__token',
+                                       'gitlab-host')
+    assert 'test_value' == value
+
+
 def test_get_role_variable():
     defaults = yaml.safe_load(open('playbooks/api/roles/api/defaults/main.yml'))
     variable = 'api_admin_password'
@@ -118,7 +145,7 @@ def test_get_role_variable():
 
 def test_get_role_unknown_variable():
     playbook = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
-    with pytest.raises(sh.ErrorReturnCode_2):
+    with pytest.raises(ansible_utils.AnsibleVariableNotFound):
         playbook.get_role_variable('api', 'inexistent_role_variable', 'api-host')
 
 
@@ -201,7 +228,8 @@ def test_ansible_inventory():
     assert '_meta' in i
 
 
-def test_get_groups():
+def test_get_groups(monkeypatch):
+    monkeypatch.setenv('ANSIBLE_VERBOSITY', '2')
     i = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR).get_groups()
     assert 'all-hosts' in i
 
