@@ -9,22 +9,58 @@ from enough.common.dotenough import Hosts, DotEnoughLibvirt
 
 @pytest.mark.libvirt_integration
 def test_libvirt_install(dotenough_libvirt_fixture):
-    lv = libvirt.Libvirt(dotenough_libvirt_fixture.config_dir, '.',
+    config_dir = dotenough_libvirt_fixture.config_dir
+    open(f'{config_dir}/hypervisor.conf', 'w').write('SOME')
+    sh.tar('zcvf', 'hypervisor.tar.gz', 'hypervisor.conf', _cwd=config_dir)
+    clouds = 'CLOUDS: cool'
+    all_dir = f'{config_dir}/inventory/group_vars/all'
+    open(f'{all_dir}/clouds.yml', 'w').write(clouds)
+
+    lv = libvirt.Libvirt(config_dir, '.',
                          domain=dotenough_libvirt_fixture.domain)
     info = lv.create_or_update([dotenough_libvirt_fixture.prefix])
     assert info[dotenough_libvirt_fixture.prefix]['port'] == '22'
     hypervisor_ip = info[dotenough_libvirt_fixture.prefix]['ipv4']
-    assert libvirt.libvirt_install(dotenough_libvirt_fixture.config_dir, '.',
-                                   dotenough_libvirt_fixture.domain,
-                                   hypervisor_ip) is True
-    hosts = Hosts(dotenough_libvirt_fixture.config_dir)
-    dotenough = DotEnoughLibvirt(dotenough_libvirt_fixture.config_dir,
+    assert libvirt.libvirt_install(config_dir, '.',
+                                   host=hypervisor_ip,
+                                   vpn="hypervisor.tar.gz") is True
+    hosts = Hosts(config_dir)
+    dotenough = DotEnoughLibvirt(config_dir,
                                  dotenough_libvirt_fixture.domain)
     assert hosts.get_ip('libvirt-hypervisor') == hypervisor_ip
+
     assert sh.ssh('-oStrictHostKeyChecking=no',
                   '-i', dotenough.private_key(), f'debian@{hypervisor_ip}',
                   'which', 'virsh').exit_code == 0
 
+    r = sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', dotenough.private_key(), f'debian@{hypervisor_ip}',
+               'docker', 'version')
+    assert 'Docker Engine' in r.stdout.decode('utf-8')
+
+    hypervisor_dotenough = f'/home/debian/.enough/{dotenough_libvirt_fixture.domain}'
+    r = sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', dotenough.private_key(), f'debian@{hypervisor_ip}',
+               'cat', f'{hypervisor_dotenough}/inventory/group_vars/all/clouds.yml')
+    assert clouds in r.stdout.decode('utf-8')
+
+    r = sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', dotenough.private_key(), f'debian@{hypervisor_ip}',
+               'systemctl', 'list-units', '--all', 'openvpn*')
+    # print('====================================')
+    # print(r.stdout.decode('utf-8'))
+    assert 'openvpn-client@hypervisor' in r.stdout.decode('utf-8')
+
+    r = sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', dotenough.private_key(), f'debian@{hypervisor_ip}',
+               'ssh', 'debian@127.0.0.1', 'uname')
+    assert 'Linux' in r.stdout.decode('utf-8')
+
+    r = sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', dotenough.private_key(), f'debian@{hypervisor_ip}',
+               'crontab', '-l')
+    assert 'enough-download' in r.stdout.decode('utf-8')
+
 
 @pytest.mark.libvirt_integration
 def test_libvirt_network_all(dotenough_libvirt_fixture):
