@@ -3,7 +3,7 @@ import json
 from enough import cmd
 
 
-def test_service(capsys, mocker):
+def test_service(capsys, mocker, tmp_config_dir):
     # do not tamper with logging streams to avoid
     # ValueError: I/O operation on closed file.
     mocker.patch('cliff.app.App.configure_logging')
